@@ -18,14 +18,14 @@
 */
 #include "kmessage.h"
 
-#include <QtCore/QLatin1String>
+#include <QLatin1String>
 
 #include <iostream>
 
 class StaticMessageHandler
 {
 public:
-    StaticMessageHandler() : m_handler(nullptr) {}
+    StaticMessageHandler() {}
     ~StaticMessageHandler()
     {
         delete m_handler;
@@ -42,7 +42,7 @@ public:
     }
 
 protected:
-    KMessageHandler *m_handler;
+    KMessageHandler *m_handler = nullptr;
 };
 Q_GLOBAL_STATIC(StaticMessageHandler, s_messageHandler)
 
